@@ -271,8 +271,8 @@ FlushOverTmpFile(void)
             *p++ = '\0';
             *q++ = '\0';
             *r++ = '\0';
-            arrived = (time_t) atol(p);
-            expires = (time_t) atol(q);
+            arrived = (time_t) atoll(p);
+            expires = (time_t) atoll(q);
             q = r;
             if ((r = strchr(r, '\t')) == NULL) {
                 warn("sorted overview file %s has a bad line at %d",
@@ -284,8 +284,8 @@ FlushOverTmpFile(void)
             *p++ = '\0';
             *q++ = '\0';
             *r++ = '\0';
-            arrived = (time_t) atol(line);
-            expires = (time_t) atol(p);
+            arrived = (time_t) atoll(line);
+            expires = (time_t) atoll(p);
         }
         token = TextToToken(q);
         if (OVadd(token, r, strlen(r), arrived, expires) == OVADDFAILED) {
@@ -338,8 +338,8 @@ WriteOverLine(TOKEN *token, const char *xrefs, int xrefslen, char *overdata,
     /* If WriteStdout is set, just print the overview information to standard
        output and return. */
     if (WriteStdout) {
-        printf("%s %ld %ld ", TokenToText(*token), (long) arrived,
-               (long) expires);
+        printf("%s %lu %lu ", TokenToText(*token), (unsigned long) arrived,
+               (unsigned long) expires);
         fwrite(overdata, 1, overlen, stdout);
         fputc('\n', stdout);
         return;
@@ -350,8 +350,8 @@ WriteOverLine(TOKEN *token, const char *xrefs, int xrefslen, char *overdata,
        process or to the overview database directly. */
     if (sorttype == OVNOSORT) {
         if (Fork) {
-            fprintf(Overchan, "%s %ld %ld ", TokenToText(*token),
-                    (long) arrived, (long) expires);
+            fprintf(Overchan, "%s %lu %lu ", TokenToText(*token),
+                    (unsigned long) arrived, (unsigned long) expires);
             if (fwrite(overdata, 1, overlen, Overchan) != (size_t) overlen)
                 sysdie("writing overview failed");
             fputc('\n', Overchan);
@@ -598,12 +598,12 @@ DoArt(ARTHANDLE *art)
     static char SEP[] = "\t";
     static char NUL[] = "\0";
     static char COLONSPACE[] = ": ";
-    size_t i, j, len;
+    size_t i, j;
     const char *MessageID;
     time_t Arrived;
     time_t Expires;
     time_t Posted;
-    char overdata[BIG_BUFFER];
+    char *overdata = NULL;
     char Bytes[BIG_BUFFER];
     char Lines[BIG_BUFFER];
     struct artngnum ann;
@@ -723,17 +723,12 @@ DoArt(ARTHANDLE *art)
         } else {
             if (ann.artnum == 0 || ann.groupname == NULL)
                 return;
-            len = strlen(innconf->pathhost) + 1 + strlen(ann.groupname) + 1
-                  + 16 + 1;
-            if (len > BIG_BUFFER) {
-                Xrefp->Header = NULL;
-                Xrefp->HeaderLength = 0;
-            } else {
-                snprintf(overdata, sizeof(overdata), "%s %s:%lu",
-                         innconf->pathhost, ann.groupname, ann.artnum);
-                Xrefp->Header = overdata;
-                Xrefp->HeaderLength = strlen(overdata);
-            }
+
+            xasprintf(&overdata, "%s %s:%lu", innconf->pathhost, ann.groupname,
+                      ann.artnum);
+            Xrefp->Header = overdata;
+            Xrefp->HeaderLength = strlen(overdata);
+
             if (ann.groupname != NULL)
                 free(ann.groupname);
         }
@@ -826,6 +821,8 @@ DoArt(ARTHANDLE *art)
         }
         WriteOverLine(art->token, Xrefp->Header, Xrefp->HeaderLength,
                       buffer.data, buffer.left, Arrived, Expires);
+        if (overdata != NULL)
+            free(overdata);
     }
 
     if (!NoHistory) {
@@ -985,7 +982,7 @@ main(int argc, char **argv)
 
     /* Change to the runasuser user and runasgroup group if necessary. */
     if (!NoHistory || !WriteStdout) {
-        if (getenv("INN_TESTSUITE") == NULL)
+        if (getenv(INN_ENV_TESTSUITE) == NULL)
             ensure_news_user_grp(true, true);
     }
 
@@ -1077,7 +1074,8 @@ main(int argc, char **argv)
         if (!WriteStdout) {
             if ((F = fopen(RebuiltflagPath, "w")) == NULL)
                 sysdie("cannot open %s", RebuiltflagPath);
-            if (fprintf(F, "%ld\n", (long) time(NULL)) == EOF || ferror(F))
+            if (fprintf(F, "%lu\n", (unsigned long) time(NULL)) == EOF
+                || ferror(F))
                 sysdie("cannot write rebuilt flag file");
             fclose(F);
         }
