@@ -53,13 +53,15 @@ typedef struct {
     bool filtered;            /* Article was marked by a filter */
     char *groups;             /* Where Newsgroups header field body starts */
     int groupslen;            /* Length of Newsgroups header field body */
+    char *path;               /* Where Path header field body starts */
+    int pathlen;              /* Length of Path header field body */
     TOKEN *token;             /* A pointer to the article's TOKEN */
 } ARTHANDLE;
 
 /* Initializer for the ARTHANDLE structure. */
-#define ARTHANDLE_INITIALIZER                 \
-    {                                         \
-        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 \
+#define ARTHANDLE_INITIALIZER                       \
+    {                                               \
+        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 \
     }
 
 #define SMERR_NOERROR    0
