@@ -486,7 +486,7 @@ ICDwriteactive(void)
 {
 #ifdef HAVE_MMAP
     if (inn_msync_page(ICDactpointer, ICDactsize, MS_ASYNC) < 0) {
-        syslog(L_FATAL, "%s msync failed %s 0x%p %d %m", LogName, ICDactpath,
+        syslog(L_FATAL, "%s msync failed %s %p %d %m", LogName, ICDactpath,
                (void *) ICDactpointer, ICDactsize);
         exit(1);
     }
