@@ -429,19 +429,22 @@ SITEwritefromflags(SITE *sp, ARTDATA *Data)
         case FEED_TIMERECEIVED:
             if (Dirty)
                 buffer_append(bp, ITEMSEP, strlen(ITEMSEP));
-            snprintf(pbuff, sizeof(pbuff), "%ld", (long) Data->Arrived);
+            snprintf(pbuff, sizeof(pbuff), "%lu",
+                     (unsigned long) Data->Arrived);
             buffer_append(bp, pbuff, strlen(pbuff));
             break;
         case FEED_TIMEPOSTED:
             if (Dirty)
                 buffer_append(bp, ITEMSEP, strlen(ITEMSEP));
-            snprintf(pbuff, sizeof(pbuff), "%ld", (long) Data->Posted);
+            snprintf(pbuff, sizeof(pbuff), "%lu",
+                     (unsigned long) Data->Posted);
             buffer_append(bp, pbuff, strlen(pbuff));
             break;
         case FEED_TIMEEXPIRED:
             if (Dirty)
                 buffer_append(bp, ITEMSEP, strlen(ITEMSEP));
-            snprintf(pbuff, sizeof(pbuff), "%ld", (long) Data->Expires);
+            snprintf(pbuff, sizeof(pbuff), "%lu",
+                     (unsigned long) Data->Expires);
             buffer_append(bp, pbuff, strlen(pbuff));
             break;
         case FEED_MESSAGEID:
@@ -503,7 +506,7 @@ SITEsend(SITE *sp, ARTDATA *Data)
 
     switch (sp->Type) {
     default:
-        syslog(L_ERROR, "%s internal SITEsend type %d", sp->Name, sp->Type);
+        syslog(L_ERROR, "%s internal SITEsend type %u", sp->Name, sp->Type);
         break;
     case FTlogonly:
         break;
@@ -721,7 +724,7 @@ SITEsetup(SITE *sp)
 
     switch (sp->Type) {
     default:
-        syslog(L_ERROR, "%s internal SITEsetup %d", sp->Name, sp->Type);
+        syslog(L_ERROR, "%s internal SITEsetup %u", sp->Name, sp->Type);
         return false;
     case FTfunnel:
     case FTlogonly:
@@ -780,15 +783,17 @@ SITEsetup(SITE *sp)
 void
 SITEprocdied(SITE *sp, int process, PROCESS *pp)
 {
-    syslog(pp->Status ? L_ERROR : L_NOTICE, "%s exit %d elapsed %ld pid %ld",
+    CHANNEL *cp;
+
+    syslog(pp->Status ? L_ERROR : L_NOTICE, "%s exit %d elapsed %lu pid %ld",
            sp->Name ? sp->Name : "?", pp->Status,
-           (long) (pp->Collected - pp->Started), (long) pp->Pid);
+           (unsigned long) (pp->Collected - pp->Started), (long) pp->Pid);
     if (sp->Process != process || sp->Name == NULL)
         /* We already started a new process for this channel
          * or this site has been dropped. */
         return;
-    if (sp->Channel != NULL)
-        CHANclose(sp->Channel, CHANname(sp->Channel));
+    if ((cp = sp->Channel) != NULL && cp->Type != CTfree)
+        CHANclose(cp, CHANname(cp));
     sp->Working = SITEsetup(sp);
     if (!sp->Working) {
         syslog(L_ERROR, "%s cant restart %m", sp->Name);
@@ -846,7 +851,7 @@ SITEflush(SITE *sp, const bool Restart)
 
     switch (sp->Type) {
     default:
-        syslog(L_ERROR, "%s internal SITEflush %d", sp->Name, sp->Type);
+        syslog(L_ERROR, "%s internal SITEflush %u", sp->Name, sp->Type);
         return;
 
     case FTlogonly:
@@ -1187,7 +1192,7 @@ SITEinfo(struct buffer *bp, SITE *sp, const bool Verbose)
 
     switch (sp->Type) {
     default:
-        buffer_append_sprintf(bp, "unknown feed type %d", sp->Type);
+        buffer_append_sprintf(bp, "unknown feed type %u", sp->Type);
         break;
     case FTerror:
     case FTfile:
