@@ -149,7 +149,7 @@ static int timeoutQueueLength;
 /* Create a new EndPoint and hook it to the give file descriptor. All
    fields are initialized to appropriate values.  On the first time this
    function is called the global data structs that manages lists of
-   endpoints are intialized. */
+   endpoints are initialized. */
 static bool inited = false;
 
 EndPoint
@@ -174,7 +174,7 @@ newEndPoint(int fd)
             if (close(fd) != 0)
                 syswarn("ME oserr close (%d)", fd);
         } else {
-            d_printf(1, "Couldn't dup fd %d to above %d\n", fd, stdioFdMax);
+            d_printf(1, "Couldn't dup fd %d to above %u\n", fd, stdioFdMax);
             newfd = fd;
         }
 
@@ -415,8 +415,8 @@ prepareWake(EndpTCB func, time_t timeToWake, void *clientData)
     id = timerElemAdd(timeToWake, func, clientData);
 
 #if defined(INNFEED_DEBUG)
-    d_printf(1, "Preparing wake %d at date %ld for %ld seconds\n", (int) id,
-             (long) now, (long) (timeToWake - now));
+    d_printf(1, "Preparing wake %d at date %lu for %ld seconds\n", (int) id,
+             (unsigned long) now, (long) (timeToWake - now));
 #endif
 
     return id;
@@ -433,8 +433,8 @@ prepareSleep(EndpTCB func, int timeToSleep, void *clientData)
     id = timerElemAdd(now + timeToSleep, func, clientData);
 
 #if defined(INNFEED_DEBUG)
-    d_printf(1, "Preparing sleep %d at date %ld for %ld seconds\n", (int) id,
-             (long) now, (long) timeToSleep);
+    d_printf(1, "Preparing sleep %d at date %lu for %ld seconds\n", (int) id,
+             (unsigned long) now, (long) timeToSleep);
 #endif
 
     return id;
@@ -629,7 +629,7 @@ Run(void)
 
                             FD_CLR(fd, &rdSet);
 
-                            /* incase callback wants to issue read */
+                            /* in case callback wants to issue read */
                             ep->inBuffer = NULL;
 
                             if (ep->inCbk != NULL)
@@ -662,7 +662,7 @@ Run(void)
 
                             FD_CLR(fd, &wrSet);
 
-                            /* incase callback wants to issue a write */
+                            /* in case callback wants to issue a write */
                             ep->outBuffer = NULL;
 
                             if (ep->outDoneCbk != NULL)
@@ -962,7 +962,7 @@ doWrite(EndPoint endp)
                     endp->outIndex = 0;
                     writeAmt -= vp[idx].iov_len;
                 } else {
-                    /* this buffer was not completly written */
+                    /* this buffer was not completely written */
                     endp->outIndex += writeAmt;
                     writeAmt = 0;
                 }
@@ -1293,8 +1293,8 @@ printDate(TimeoutId tid, void *data)
     const time_t t = theTime();
 
     timeToString(t, dateString, sizeof(dateString));
-    d_printf(1, "Timeout (%d) time now is %ld %s\n", (int) tid, (long) t,
-             dateString);
+    d_printf(1, "Timeout (%d) time now is %lu %s\n", (int) tid,
+             (unsigned long) t, dateString);
 
     if (timeoutQueue == NULL) {
         int ti = (rand() % 10) + 1;
@@ -1320,8 +1320,8 @@ Timeout(TimeoutId tid, void *data)
     }
 
     timeToString(t, dateString, sizeof(dateString));
-    d_printf(1, "Timeout (%d) time now is %ld %s\n", (int) tid, (long) t,
-             dateString);
+    d_printf(1, "Timeout (%d) time now is %lu %s\n", (int) tid,
+             (unsigned long) t, dateString);
 
     if (timeoutQueue != NULL && timeoutQueue->next != NULL)
         d_printf(1, "%s timeout id %d\n",
