@@ -1,9 +1,9 @@
 /*
-**  Routines for NNTP commands:  manipulation and checks.
+**  Routines for NNTP commands: manipulation and checks.
 */
 
-#include "config.h"
-#include "clibrary.h"
+#include "portable/system.h"
+
 #include <ctype.h>
 
 #include "inn/libinn.h"
@@ -30,7 +30,8 @@ IsValidKeyword(const char *string)
         return false;
 
     for (; *string != '\0'; string++) {
-        if (isalnum((unsigned char) *string) || *string == '.' || *string == '-')
+        if (isalnum((unsigned char) *string) || *string == '.'
+            || *string == '-')
             len++;
         else
             return false;
