@@ -107,7 +107,7 @@ static const struct config config_table[] = {
     {K(pathspool),                  STRING(NULL)      },
     {K(pathtmp),                    STRING(NULL)      },
 
- /* The following settings are specific to innd. */
+    /* The following settings are specific to innd. */
     {K(artcutoff),                  UNUMBER(10)       },
     {K(badiocount),                 UNUMBER(5)        },
     {K(bindaddress),                STRING(NULL)      },
@@ -150,7 +150,7 @@ static const struct config config_table[] = {
     {K(wipexpire),                  UNUMBER(10)       },
     {K(xrefslave),                  BOOL(false)       },
 
- /* The following settings are specific to nnrpd. */
+    /* The following settings are specific to nnrpd. */
     {K(addinjectiondate),           BOOL(true)        },
     {K(addinjectionpostingaccount), BOOL(false)       },
     {K(addinjectionpostinghost),    BOOL(true)        },
@@ -198,11 +198,11 @@ static const struct config config_table[] = {
     {K(tlsprotocols),               LIST(NULL)        },
 #endif  /* HAVE_OPENSSL */
 
-  /* The following settings are used by nnrpd and rnews. */
+    /* The following settings are used by nnrpd and rnews. */
     {K(nnrpdposthost),              STRING(NULL)      },
     {K(nnrpdpostport),              UNUMBER(119)      },
 
- /* The following settings are specific to the storage subsystem. */
+    /* The following settings are specific to the storage subsystem. */
     {K(articlemmap),                BOOL(true)        },
     {K(cnfscheckfudgesize),         UNUMBER(0)        },
     {K(immediatecancel),            BOOL(false)       },
@@ -217,15 +217,15 @@ static const struct config config_table[] = {
     {K(useoverchan),                BOOL(false)       },
     {K(wireformat),                 BOOL(true)        },
 
- /* The following settings are specific to the history subsystem. */
+    /* The following settings are specific to the history subsystem. */
     {K(hismethod),                  STRING(NULL)      },
 
- /* The following settings are specific to rc.news. */
+    /* The following settings are specific to rc.news. */
     {K(docnfsstat),                 BOOL(false)       },
     {K(innflags),                   STRING(NULL)      },
     {K(pgpverify),                  BOOL(false)       },
 
- /* The following settings are specific to innwatch. */
+    /* The following settings are specific to innwatch. */
     {K(doinnwatch),                 BOOL(true)        },
     {K(innwatchbatchspace),         UNUMBER(4000)     },
     {K(innwatchlibspace),           UNUMBER(25000)    },
@@ -236,11 +236,11 @@ static const struct config config_table[] = {
     {K(innwatchspoolnodes),         UNUMBER(200)      },
     {K(innwatchspoolspace),         UNUMBER(25000)    },
 
- /* The following settings are specific to scanlogs.
-  * Keep a low value by default as it has a privacy impact; three days
-  * should be enough to diagnose the most common cases of malfunction
-  * and abuse.  Where more is needed, it is easy for the news admin
-  * to increase it. */
+    /* The following settings are specific to scanlogs.
+     * Keep a low value by default as it has a privacy impact; three days
+     * should be enough to diagnose the most common cases of malfunction
+     * and abuse.  Where more is needed, it is easy for the news admin
+     * to increase it. */
     {K(logcycles),                  UNUMBER(3)        },
 };
 
@@ -257,31 +257,31 @@ innconf_set_defaults(void)
     char *value;
 
     /* Some environment variables override settings in inn.conf. */
-    value = getenv("FROMHOST");
+    value = getenv(INN_ENV_FROMHOST);
     if (value != NULL) {
         if (innconf->fromhost != NULL)
             free(innconf->fromhost);
         innconf->fromhost = xstrdup(value);
     }
-    value = getenv("NNTPSERVER");
+    value = getenv(INN_ENV_NNTPSERVER);
     if (value != NULL) {
         if (innconf->server != NULL)
             free(innconf->server);
         innconf->server = xstrdup(value);
     }
-    value = getenv("ORGANIZATION");
+    value = getenv(INN_ENV_ORGANIZATION);
     if (value != NULL) {
         if (innconf->organization != NULL)
             free(innconf->organization);
         innconf->organization = xstrdup(value);
     }
-    value = getenv("INND_BIND_ADDRESS");
+    value = getenv(INN_ENV_INNBINDADDR);
     if (value != NULL) {
         if (innconf->bindaddress != NULL)
             free(innconf->bindaddress);
         innconf->bindaddress = xstrdup(value);
     }
-    value = getenv("INND_BIND_ADDRESS6");
+    value = getenv(INN_ENV_INNBINDADDR6);
     if (value != NULL) {
         if (innconf->bindaddress6 != NULL)
             free(innconf->bindaddress6);
@@ -447,17 +447,16 @@ innconf_validate(struct config_group *group)
     /* Checks to ensure valid Message-IDs will be generated. */
     fqdn = inn_getfqdn(innconf->domain);
     if (fqdn == NULL) {
-        warn("hostname does not resolve or domain not set in inn.conf");
-        okay = false;
+        warn("fully qualified hostname not found; see domain in inn.conf");
     }
     if (innconf->domain != NULL && !IsValidDomain(innconf->domain)) {
         warn("domain in inn.conf contains invalid characters not suitable for "
              "Message-IDs");
         okay = false;
     }
-    if (innconf->domain == NULL && !IsValidDomain(fqdn)) {
+    if (innconf->domain == NULL && fqdn != NULL && !IsValidDomain(fqdn)) {
         warn("the FQDN of the server contains invalid characters not suitable "
-             "for Message-IDs");
+             "for Message-IDs; see domain in inn.conf");
         okay = false;
     }
     free(fqdn);
@@ -613,7 +612,7 @@ innconf_read(const char *path)
     if (innconf != NULL)
         innconf_free(innconf);
     if (path == NULL)
-        path = getenv("INNCONF");
+        path = getenv(INN_ENV_INNCONF);
     group = config_parse_file(path == NULL ? INN_PATH_CONFIG : path);
     if (group == NULL)
         return false;
@@ -626,9 +625,9 @@ innconf_read(const char *path)
 
     /* It's not clear that this belongs here, but it was done by the old
        configuration parser, so this is a convenient place to do it. */
-    tmpdir = getenv("TMPDIR");
+    tmpdir = getenv(INN_ENV_TMPDIR);
     if (tmpdir == NULL || strcmp(tmpdir, innconf->pathtmp) != 0)
-        if (setenv("TMPDIR", innconf->pathtmp, true) != 0) {
+        if (setenv(INN_ENV_TMPDIR, innconf->pathtmp, true) != 0) {
             warn("cannot set TMPDIR in the environment");
             return false;
         }
@@ -658,7 +657,7 @@ innconf_check(const char *path)
     if (innconf != NULL)
         innconf_free(innconf);
     if (path == NULL)
-        path = getenv("INNCONF");
+        path = getenv(INN_ENV_INNCONF);
     group = config_parse_file(path == NULL ? INN_PATH_CONFIG : path);
     if (group == NULL)
         return false;
