@@ -534,7 +534,7 @@ CMDnewgroups(int ac, char *av[])
         if ((q = strchr(p, ' ')) == NULL)
             continue;
         *q++ = '\0';
-        if ((time_t) atol(q) < date)
+        if ((time_t) atoll(q) < date)
             continue;
         if (!OVgroupstats(p, &lo, &hi, &count, &flag))
             continue;
@@ -757,7 +757,7 @@ CMDpost(int ac, char *av[])
                       NULL);
         switch (r) {
         default:
-            warn("%s internal %d in post", Client.host, r);
+            warn("%s internal %u in post", Client.host, r);
             goto fallthrough;
         case RTtimeout:
         fallthrough:
