@@ -28,11 +28,6 @@ enum {
 #include "nnrpd.h"
 #include "tls.h"
 
-/* Needed on AIX 4.1 to get fd_set and friends. */
-#ifdef HAVE_SYS_SELECT_H
-#    include <sys/select.h>
-#endif
-
 /* Data types. */
 typedef struct _CONFCHAIN {
     CONFFILE *f;
@@ -500,6 +495,7 @@ SetDefaultAccess(ACCESSGROUP *curaccess)
     curaccess->domain = NULL;
     if (innconf->domain)
         curaccess->domain = xstrdup(innconf->domain);
+    curaccess->domainoverriden = false;
     curaccess->complaints = NULL;
     if (innconf->complaints)
         curaccess->complaints = xstrdup(innconf->complaints);
@@ -980,10 +976,22 @@ accessdecl_parse(ACCESSGROUP *curaccess, CONFFILE *f, CONFTOKEN *tok)
         SET_CONFIG(oldtype);
         break;
     case PERMdomain:
-        if (curaccess->domain)
+        if (curaccess->domain) {
+            /* Should we use domain from readers.conf to generate Message-IDs?
+             * This weird check will be changed in a future version, when a new
+             * servername parameter is introduced, instead of using domain for
+             * something it was not designed for. */
+            curaccess->domainoverriden = true;
             free(curaccess->domain);
+        }
         curaccess->domain = xstrdup(tok->name);
         SET_CONFIG(oldtype);
+        if (!IsValidDomain(curaccess->domain)) {
+            snprintf(buff, sizeof(buff),
+                     "Invalid characters in domain '%s' used in Message-IDs.",
+                     tok->name);
+            ReportError(f, buff);
+        }
         break;
     case PERMcomplaints:
         if (curaccess->complaints)
@@ -1860,7 +1868,8 @@ PERMgetpermissions(void)
                            == 0) {
                     syslog(L_ERROR,
                            "%s domain parameter (%s) in readers.conf must be "
-                           "different from the one in inn.conf.",
+                           "different from the one in inn.conf (or use a "
+                           "different pathhost in readers.conf and inn.conf).",
                            Client.host, PERMaccessconf->name);
                     Reply("%d NNTP server unavailable.  Try later!\r\n",
                           NNTP_FAIL_TERMINATING);
